@@ -7,7 +7,6 @@ Authors: David Malcolm <dmalcolm@redhat.com>
 
 __author__ = """David Malcolm <dmalcolm@redhat.com>, Zack Cerza <zcerza@redhat.com>"""
 
-import distro
 import config
 
 import os
@@ -206,12 +205,20 @@ def isMoFile(filename, language = ''):
     else:
         return False
 
+def loadAllTranslationsForLanguage(language):
+    import distro
+    result = []
+    for moFile in distro.packageDb.getMoFiles(language):
+        translationDbs.append(GettextTranslationDb(moFile))
+
 def getMoFilesForPackage(packageName, language = '', getDependencies=True):
     """
     Look up the named package and find all gettext mo files within it and its
     dependencies. It is possible to restrict the results to those of a certain
     language, for example 'ja'.
     """
+    import distro
+
     result = []
     for filename in distro.packageDb.getFiles(packageName):
         if isMoFile(filename, language):
@@ -238,7 +245,7 @@ def loadTranslationsFromPackageMoFiles(packageName, getDependencies=True):
             # Searching the popt mo-files for translations makes gettext bail out,
             # so we ignore them here. This is
             # https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=172155 .
-            if 'popt.mo' not in moFile:
+            if not('popt.mo' in moFile or moFile in moFiles):
                 try:
                     translationDbs.append(GettextTranslationDb(moFile))
                     moFiles[moFile] = None
@@ -255,6 +262,7 @@ def loadTranslationsFromPackageMoFiles(packageName, getDependencies=True):
     # this special case, aside from the simple fact that there is one,
     # is that it makes automatic translations much slower.
 
+    import distro
     language = os.environ.get('LANGUAGE', os.environ['LANG'])[0:2]
     if isinstance(distro.distro, distro.Ubuntu):
         load('language-pack-gnome-%s' % language, language)
